==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/inputs/UserHierarchyStructureHierarchyStructureLevelTwoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.inputs

import com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property arn The Amazon Resource Name (ARN) of the hierarchy level.
 * @property id The identifier of the hierarchy level.
 * @property name The name of the user hierarchy level. Must not be more than 50 characters.
 */
public data class UserHierarchyStructureHierarchyStructureLevelTwoArgs(
    public val arn: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs> {
    override fun toJava():
        com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs =
        com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs.builder()
            .arn(arn?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserHierarchyStructureHierarchyStructureLevelTwoArgs].
 */
@PulumiTagMarker
public class UserHierarchyStructureHierarchyStructureLevelTwoArgsBuilder internal constructor() {
    private var arn: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value The Amazon Resource Name (ARN) of the hierarchy level.
     */
    @JvmName("xaijnaqserbygkir")
    public suspend fun arn(`value`: Output<String>) {
        this.arn = value
    }

    /**
     * @param value The identifier of the hierarchy level.
     */
    @JvmName("rgtqkqmwqvdsgdkg")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the user hierarchy level. Must not be more than 50 characters.
     */
    @JvmName("mvhmldwgvaxlmyyw")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the hierarchy level.
     */
    @JvmName("uxvgpctjdgaggayn")
    public suspend fun arn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.arn = mapped
    }

    /**
     * @param value The identifier of the hierarchy level.
     */
    @JvmName("ektgkuodbfnayvqr")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the user hierarchy level. Must not be more than 50 characters.
     */
    @JvmName("gajaurhhgnbwcefg")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): UserHierarchyStructureHierarchyStructureLevelTwoArgs =
        UserHierarchyStructureHierarchyStructureLevelTwoArgs(
            arn = arn,
            id = id,
            name = name ?: throw PulumiNullFieldException("name"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/inputs/UserHierarchyStructureHierarchyStructureLevelTwoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.inputs

import com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property arn The Amazon Resource Name (ARN) of the hierarchy level.
 * @property id The identifier of the hierarchy level.
 * @property name The name of the user hierarchy level. Must not be more than 50 characters.
 */
public data class UserHierarchyStructureHierarchyStructureLevelTwoArgs(
    public val arn: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs> {
    override fun toJava(): com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs =
        com.pulumi.aws.connect.inputs.UserHierarchyStructureHierarchyStructureLevelTwoArgs.builder()
            .arn(arn?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserHierarchyStructureHierarchyStructureLevelTwoArgs].
 */
@PulumiTagMarker
public class UserHierarchyStructureHierarchyStructureLevelTwoArgsBuilder internal constructor() {
    private var arn: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value The Amazon Resource Name (ARN) of the hierarchy level.
     */
    @JvmName("vopdfxffmfemfrep")
    public suspend fun arn(`value`: Output<String>) {
        this.arn = value
    }

    /**
     * @param value The identifier of the hierarchy level.
     */
    @JvmName("fuqbvyggslmddblh")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the user hierarchy level. Must not be more than 50 characters.
     */
    @JvmName("ukcdibmrvejgqjai")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the hierarchy level.
     */
    @JvmName("bvqaphskrcumqcvh")
    public suspend fun arn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.arn = mapped
    }

    /**
     * @param value The identifier of the hierarchy level.
     */
    @JvmName("awxmhwmfiueepfrd")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the user hierarchy level. Must not be more than 50 characters.
     */
    @JvmName("uyfnhegovyejpewh")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): UserHierarchyStructureHierarchyStructureLevelTwoArgs =
        UserHierarchyStructureHierarchyStructureLevelTwoArgs(
            arn = arn,
            id = id,
            name = name ?: throw PulumiNullFieldException("name"),
        )
}
